# bluenaas_capabilities
A SciUnit library for handling NEURON-Python models having different internal implementations/formats.

To install:
`pip install bluenaas_capabilities`

<div><img src="https://raw.githubusercontent.com/appukuttan-shailesh/bluenaas_capabilities/master/eu_logo.jpg" alt="EU Logo" width="15%" align="right"></div>

### ACKNOWLEDGEMENTS
This open source software code was developed in part or in whole in the Human Brain Project, funded from the European Union's Horizon 2020 Framework Programme for Research and Innovation under Specific Grant Agreements No. 720270 and No. 785907 (Human Brain Project SGA1 and SGA2).
